@@ -2,6 +2,7 @@
 from gnip_rules.gnip_rules import *
 from gnip_rules.gnip_config import *
 from optparse import OptionParser
+import fileinput
 import sys
 import csv
 
@@ -13,8 +14,7 @@ parser.add_option("-s", "--update-rule", dest="r2", default=None,
             help="Replacement rule.")
 parser.add_option("-t", "--update-tag", dest="t2", default=None, 
             help="Replacement rule tag.")
-parser.add_option("-f", "--tab-file", dest="tab", default=False, action="store_true",
-            help="Stdin containing list of updates 'rule1<tab>rule2<tab>tab2'")
+# add json processor?
 (options, args) = parser.parse_args()
 
 if options.url is not None:
@@ -25,14 +25,12 @@ else:
     print >>sys.stderr, "No url provided. Add [defaults] url=... to config file or use -u ..."
     sys.exit()
 
-if options.tab:
-    for row in sys.stdin:
-        [r, s, t] = row.split("\t") 
-        g.updateRule(r, s, tag=t.strip())
-        print g.getResponse()
-elif options.r1 is not None and options.r2 is not None:
+if options.r1 is not None and options.r2 is not None:
     g.updateRule(options.r1, options.r2, tag=options.t2)
     print g.getResponse()
 else:
-    print >>sys.stderr, "=== Use -r -s options or provide file. ==="
+    for row in fileinput.FileInput(args,openhook=fileinput.hook_compressed):
+        [r, s, t] = row.split("\t") 
+        g.updateRule(r.strip(), s.strip(), tag=t.strip())
+        print g.getResponse()
 
